@@ -6,7 +6,7 @@ use Moo;
 use HTML::TableContent::Parser;
 use HTML::TableContent::Table;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 has parser => (
     is      => 'rw',
@@ -259,7 +259,7 @@ HTML::TableContent - HTML tables.
 
 =head1 VERSION
 
-Version 1.00 
+Version 1.01 
 
 =cut
 
@@ -516,14 +516,6 @@ You can also look for information at:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-TableContent>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/HTML-TableContent>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/HTML-TableContent>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/HTML-TableContent/>
@@ -540,7 +532,7 @@ L<http://search.cpan.org/dist/HTML-TableContent/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2016->2020 LNATION.
+Copyright 2016->2025 LNATION.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
